@@ -21,7 +21,6 @@ typedef Eo Efl_Vpath_File_Core;
  */
 #define EFL_VPATH_FILE_CORE_CLASS efl_vpath_file_core_class_get()
 
-EWAPI const Eo_Class *efl_vpath_file_core_class_get(void);
-
+EWAPI const Efl_Class *efl_vpath_file_core_class_get(void);
 
 #endif
