@@ -23,40 +23,40 @@ typedef Eo Efl_Ui_Win;
  */
 typedef enum
 {
-  EFL_UI_WIN_UNKNOWN = -1 /* -0 */,
-  EFL_UI_WIN_BASIC, /** A normal window. Indicates a normal, top-level window.
+  EFL_UI_WIN_UNKNOWN = -1 /* +0 */, /**< Default, unknown, type */
+  EFL_UI_WIN_BASIC, /**< A normal window. Indicates a normal, top-level window.
                      * Almost every window will be created with this type. */
-  EFL_UI_WIN_DIALOG_BASIC, /** Used for simple dialog windows. */
-  EFL_UI_WIN_DESKTOP, /** For special desktop windows, like a background window
+  EFL_UI_WIN_DIALOG_BASIC, /**< Used for simple dialog windows. */
+  EFL_UI_WIN_DESKTOP, /**< For special desktop windows, like a background window
                        * holding desktop icons. */
-  EFL_UI_WIN_DOCK, /** The window is used as a dock or panel. Usually would be
+  EFL_UI_WIN_DOCK, /**< The window is used as a dock or panel. Usually would be
                     * kept on top of any other window by the Window Manager. */
-  EFL_UI_WIN_TOOLBAR, /** The window is used to hold a floating toolbar, or
+  EFL_UI_WIN_TOOLBAR, /**< The window is used to hold a floating toolbar, or
                        * similar. */
-  EFL_UI_WIN_MENU, /** Similar to #ELM_WIN_TOOLBAR. */
-  EFL_UI_WIN_UTILITY, /** A persistent utility window, like a toolbox or
+  EFL_UI_WIN_MENU, /**< Similar to #ELM_WIN_TOOLBAR. */
+  EFL_UI_WIN_UTILITY, /**< A persistent utility window, like a toolbox or
                        * palette. */
-  EFL_UI_WIN_SPLASH, /** Splash window for a starting up application. */
-  EFL_UI_WIN_DROPDOWN_MENU, /** The window is a dropdown menu, as when an
+  EFL_UI_WIN_SPLASH, /**< Splash window for a starting up application. */
+  EFL_UI_WIN_DROPDOWN_MENU, /**< The window is a dropdown menu, as when an
                              *  entry in a menubar is clicked. This hint exists
                              * for completion only, as the EFL way of
                              * implementing a menu would not normally use a
                              * separate window for its contents. */
-  EFL_UI_WIN_POPUP_MENU, /** Like #ELM_WIN_DROPDOWN_MENU, but for the menu
+  EFL_UI_WIN_POPUP_MENU, /**< Like #ELM_WIN_DROPDOWN_MENU, but for the menu
                           * triggered by right-clicking an object. */
-  EFL_UI_WIN_TOOLTIP, /** The window is a tooltip. A short piece of explanatory
+  EFL_UI_WIN_TOOLTIP, /**< The window is a tooltip. A short piece of explanatory
                        * text that typically appear after the mouse cursor
                        * hovers over an object for a while. Typically not very
                        * commonly used in the EFL. */
-  EFL_UI_WIN_NOTIFICATION, /** A notification window, like a warning about
+  EFL_UI_WIN_NOTIFICATION, /**< A notification window, like a warning about
                             * battery life or a new E-Mail received. */
-  EFL_UI_WIN_COMBO, /** A window holding the contents of a combo box. Not
+  EFL_UI_WIN_COMBO, /**< A window holding the contents of a combo box. Not
                      * usually used in the EFL. */
-  EFL_UI_WIN_DND, /** Used to indicate the window is a representation of an
+  EFL_UI_WIN_DND, /**< Used to indicate the window is a representation of an
                    * object being dragged across different windows, or even
                    * applications. Typically used with elm_win_override_set().
                    */
-  EFL_UI_WIN_INLINED_IMAGE, /** The window is rendered onto an image buffer. No
+  EFL_UI_WIN_INLINED_IMAGE, /**< The window is rendered onto an image buffer. No
                              * actual window is created for this type, instead
                              * the window and all of its contents will be
                              * rendered to an image buffer. This allows to have
@@ -66,17 +66,21 @@ typedef enum
                              * is the only type of window that requires the
                              * parent parameter of @ref elm_win_add to be a
                              * valid @ref Efl_Canvas_Object. */
-  EFL_UI_WIN_SOCKET_IMAGE, /** The window is rendered onto an image buffer and
+  EFL_UI_WIN_SOCKET_IMAGE, /**< The window is rendered onto an image buffer and
                             * can be shown other process's plug image object.
                             * No actual window is created for this type,
                             * instead the window and all of its contents will
                             * be rendered to an image buffer and can be shown
                             * other process's plug image object. */
-  EFL_UI_WIN_FAKE /** This window was created using a pre-existing canvas. The
-                   * window widget can be deleted, but the canvas must be
-                   * managed externally.
-                   *
-                   * @since 1.13 */
+  EFL_UI_WIN_FAKE, /**< This window was created using a pre-existing canvas. The
+                    * window widget can be deleted, but the canvas must be
+                    * managed externally.
+                    *
+                    * @since 1.13 */
+  EFL_UI_WIN_NAVIFRAME_BASIC /**< Used for naviframe style replacement with a
+                              * back button instead of a close button.
+                              *
+                              * @since 1.19 */
 } Efl_Ui_Win_Type;
 
 /**
@@ -89,22 +93,22 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_KEYBOARD_UNKNOWN = 0, /** Unknown keyboard state */
-  EFL_UI_WIN_KEYBOARD_OFF, /** Request to deactivate the keyboard */
-  EFL_UI_WIN_KEYBOARD_ON, /** Enable keyboard with default layout */
-  EFL_UI_WIN_KEYBOARD_ALPHA, /** Alpha (a-z) keyboard layout */
-  EFL_UI_WIN_KEYBOARD_NUMERIC, /** Numeric keyboard layout */
-  EFL_UI_WIN_KEYBOARD_PIN, /** PIN keyboard layout */
-  EFL_UI_WIN_KEYBOARD_PHONE_NUMBER, /** Phone keyboard layout */
-  EFL_UI_WIN_KEYBOARD_HEX, /** Hexadecimal numeric keyboard layout */
-  EFL_UI_WIN_KEYBOARD_TERMINAL, /** Full (QWERTY) keyboard layout */
-  EFL_UI_WIN_KEYBOARD_PASSWORD, /** Password keyboard layout */
-  EFL_UI_WIN_KEYBOARD_IP, /** IP keyboard layout */
-  EFL_UI_WIN_KEYBOARD_HOST, /** Host keyboard layout */
-  EFL_UI_WIN_KEYBOARD_FILE, /** File keyboard layout */
-  EFL_UI_WIN_KEYBOARD_URL, /** URL keyboard layout */
-  EFL_UI_WIN_KEYBOARD_KEYPAD, /** Keypad layout */
-  EFL_UI_WIN_KEYBOARD_J2ME /** J2ME keyboard layout */
+  EFL_UI_WIN_KEYBOARD_UNKNOWN = 0, /**< Unknown keyboard state */
+  EFL_UI_WIN_KEYBOARD_OFF, /**< Request to deactivate the keyboard */
+  EFL_UI_WIN_KEYBOARD_ON, /**< Enable keyboard with default layout */
+  EFL_UI_WIN_KEYBOARD_ALPHA, /**< Alpha (a-z) keyboard layout */
+  EFL_UI_WIN_KEYBOARD_NUMERIC, /**< Numeric keyboard layout */
+  EFL_UI_WIN_KEYBOARD_PIN, /**< PIN keyboard layout */
+  EFL_UI_WIN_KEYBOARD_PHONE_NUMBER, /**< Phone keyboard layout */
+  EFL_UI_WIN_KEYBOARD_HEX, /**< Hexadecimal numeric keyboard layout */
+  EFL_UI_WIN_KEYBOARD_TERMINAL, /**< Full (QWERTY) keyboard layout */
+  EFL_UI_WIN_KEYBOARD_PASSWORD, /**< Password keyboard layout */
+  EFL_UI_WIN_KEYBOARD_IP, /**< IP keyboard layout */
+  EFL_UI_WIN_KEYBOARD_HOST, /**< Host keyboard layout */
+  EFL_UI_WIN_KEYBOARD_FILE, /**< File keyboard layout */
+  EFL_UI_WIN_KEYBOARD_URL, /**< URL keyboard layout */
+  EFL_UI_WIN_KEYBOARD_KEYPAD, /**< Keypad layout */
+  EFL_UI_WIN_KEYBOARD_J2ME /**< J2ME keyboard layout */
 } Efl_Ui_Win_Keyboard_Mode;
 
 /** Defines the type indicator that can be shown
@@ -113,19 +117,19 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_INDICATOR_TYPE_UNKNOWN = 0, /** Unknown indicator type */
-  EFL_UI_WIN_INDICATOR_BG_OPAQUE, /** The icon of indicator is opaque, the
+  EFL_UI_WIN_INDICATOR_TYPE_UNKNOWN = 0, /**< Unknown indicator type */
+  EFL_UI_WIN_INDICATOR_BG_OPAQUE, /**< The icon of indicator is opaque, the
                                    * background of indicator is also opaque.
-                                   *  The content of window is located the end
+                                   * The content of window is located the end
                                    * of indicator. The area of indicator and
                                    * window content are not overlapped */
-  EFL_UI_WIN_INDICATOR_BG_TRANSPARENT, /** The icon of indicator is opaque, but
+  EFL_UI_WIN_INDICATOR_BG_TRANSPARENT, /**< The icon of indicator is opaque, but
                                         * the background is transparent. The
                                         * content of window is located under
                                         * the indicator in Z-order. The area of
                                         * indicator and window content are
                                         * overlapped */
-  EFL_UI_WIN_INDICATOR_HIDDEN /** The indicator is hidden, So user can see only
+  EFL_UI_WIN_INDICATOR_HIDDEN /**< The indicator is hidden, So user can see only
                                * the content of window like the video mode. If
                                * user flicks the upper side of window, the
                                * incator is shown temporarily. */
@@ -138,17 +142,17 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_KEYGRAB_UNKNOWN = 0, /** Unknown keygrab mode */
-  EFL_UI_WIN_KEYGRAB_SHARED = 256 /* 0 << 0 */, /** Getting the grabbed-key
+  EFL_UI_WIN_KEYGRAB_UNKNOWN = 0, /**< Unknown keygrab mode */
+  EFL_UI_WIN_KEYGRAB_SHARED = 256 /* 0 >> 0 */, /**< Getting the grabbed-key
                                                  * together with the other
                                                  * client windows */
-  EFL_UI_WIN_KEYGRAB_TOPMOST = 512 /* 0 << 0 */, /** Getting the grabbed-key
+  EFL_UI_WIN_KEYGRAB_TOPMOST = 512 /* 0 >> 0 */, /**< Getting the grabbed-key
                                                   * only when window is top of
                                                   * the stack */
-  EFL_UI_WIN_KEYGRAB_EXCLUSIVE = 1024 /* 0 << 0 */, /** Getting the grabbed-key
+  EFL_UI_WIN_KEYGRAB_EXCLUSIVE = 1024 /* 0 >> 0 */, /**< Getting the grabbed-key
                                                      * exclusively regardless
                                                      * of window's position */
-  EFL_UI_WIN_KEYGRAB_OVERRIDE_EXCLUSIVE = 2048 /* 0 << 0 */ /** Getting the grabbed-key exclusively
+  EFL_UI_WIN_KEYGRAB_OVERRIDE_EXCLUSIVE = 2048 /* 0 >> 0 */ /**< Getting the grabbed-key exclusively
                                                              * regardless of window's position.
                                                              * Being overrided the grab by the
                                                              * other client window */
@@ -160,8 +164,8 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_MODAL_NONE = 0, /** The window is not modal window. */
-  EFL_UI_WIN_MODAL_MODAL /** The window is modal window. */
+  EFL_UI_WIN_MODAL_NONE = 0, /**< The window is not modal window. */
+  EFL_UI_WIN_MODAL_MODAL /**< The window is modal window. */
 } Efl_Ui_Win_Modal_Mode;
 
 /** Defines the mode of a urgent window.
@@ -170,15 +174,48 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_URGENT_NONE = 0, /** The window is not a urgent window. */
-  EFL_UI_WIN_URGENT_URGENT /** The window is a urgent window. */
+  EFL_UI_WIN_URGENT_NONE = 0, /**< The window is not a urgent window. */
+  EFL_UI_WIN_URGENT_URGENT /**< The window is a urgent window. */
 } Efl_Ui_Win_Urgent_Mode;
 
+/**
+ * @brief Define the move or resize mode of window.
+ *
+ * The user can request the display server to start moving or resizing the
+ * window by combining these modes. However, only limited combinations are
+ * allowed.
+ *
+ * Currently, only the following 9 combinations are allowed, and possibly more
+ * combinations may be added in the future: 1. move, 2. top, 3. bottom, 4.
+ * left, 5. right, 6. top | left, 7. top | right, 8. bottom | left, 9. bottom |
+ * right.
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Ui_Win
+ */
+typedef enum
+{
+  EFL_UI_WIN_MOVE_RESIZE_MOVE = 1 /* 0 */, /**< Start moving window */
+  EFL_UI_WIN_MOVE_RESIZE_TOP = 2 /* 0 >> 0 */, /**< Start resizing window to the
+                                                * top */
+  EFL_UI_WIN_MOVE_RESIZE_BOTTOM = 4 /* 0 >> 0 */, /**< Start resizing window to
+                                                   * the bottom */
+  EFL_UI_WIN_MOVE_RESIZE_LEFT = 8 /* 0 >> 0 */, /**< Start resizing window to
+                                                 * the left */
+  EFL_UI_WIN_MOVE_RESIZE_RIGHT = 16 /* 0 >> 0 */ /**< Start resizing window to
+                                                  * the right */
+} Efl_Ui_Win_Move_Resize_Mode;
+
 
 #endif
+/** Efl UI window class
+ *
+ * @ingroup Efl_Ui_Win
+ */
 #define EFL_UI_WIN_CLASS efl_ui_win_class_get()
 
-EWAPI const Eo_Class *efl_ui_win_class_get(void);
+EWAPI const Efl_Class *efl_ui_win_class_get(void);
 
 /**
  * @brief In some environments, like phones, you may have an indicator that
@@ -190,7 +227,7 @@ EWAPI const Eo_Class *efl_ui_win_class_get(void);
  * phones, default is to enable the indicator. But like TV, default is to
  * disable the indicator.
  *
- * @param[in] enabled If true, the indicator is enabled, If false, the
+ * @param[in] enabled If @c true, the indicator is enabled, If @c false, the
  * indicator is disabled.
  *
  * @since 1.18
@@ -209,7 +246,7 @@ EOAPI void efl_ui_win_indicator_enabled_set(Eo *obj, Eina_Bool enabled);
  * phones, default is to enable the indicator. But like TV, default is to
  * disable the indicator.
  *
- * @return If true, the indicator is enabled, If false, the indicator is
+ * @return If @c true, the indicator is enabled, If @c false, the indicator is
  * disabled.
  *
  * @since 1.18
@@ -281,6 +318,8 @@ EOAPI void efl_ui_win_wm_available_rotations_set(Eo *obj, const int *rotations,
  * @param[out] rotations The array of rotation value.
  * @param[out] count The size of the rotations array.
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @since 1.9
  *
  * @ingroup Efl_Ui_Win
@@ -398,7 +437,10 @@ EOAPI Eina_Bool efl_ui_win_focus_highlight_animate_get(const Eo *obj);
  */
 EOAPI void efl_ui_win_prop_focus_skip_set(Eo *obj, Eina_Bool skip);
 
-/** Get whether a window has focus.
+/**
+ * @brief Get whether a window has focus.
+ *
+ * @return @c true if window has focus, @c false otherwise
  *
  * @ingroup Efl_Ui_Win
  */
@@ -418,8 +460,8 @@ EOAPI Eina_Bool efl_ui_win_focus_get(const Eo *obj);
  * is @c false, then the window will not be destroyed and is up to the program
  * to do so when it's required.
  *
- * @param[in] autodel If true, the window will automatically delete itself when
- * closed.
+ * @param[in] autodel If @c true, the window will automatically delete itself
+ * when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -428,7 +470,7 @@ EOAPI void efl_ui_win_autodel_set(Eo *obj, Eina_Bool autodel);
 /**
  * @brief Get the window's autodel state.
  *
- * @return If true, the window will automatically delete itself when closed.
+ * @return If @c true, the window will automatically delete itself when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -448,8 +490,8 @@ EOAPI Eina_Bool efl_ui_win_autodel_get(const Eo *obj);
  * @note @ref efl_ui_win_autodel_get and @c autohide are not mutually
  * exclusive. The window will be deleted if both are set to @c true.
  *
- * @param[in] autohide If true, the window will automatically hide itself when
- * closed.
+ * @param[in] autohide If @c true, the window will automatically hide itself
+ * when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -469,7 +511,7 @@ EOAPI void efl_ui_win_autohide_set(Eo *obj, Eina_Bool autohide);
  * @note @ref efl_ui_win_autodel_get and @c autohide are not mutually
  * exclusive. The window will be deleted if both are set to @c true.
  *
- * @return If true, the window will automatically hide itself when closed.
+ * @return If @c true, the window will automatically hide itself when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -506,7 +548,7 @@ EOAPI const Efl_Canvas_Object *efl_ui_win_icon_object_get(const Eo *obj);
 /**
  * @brief Set the iconified state of a window.
  *
- * @param[in] iconified If true, the window is iconified.
+ * @param[in] iconified If @c true, the window is iconified.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -515,7 +557,7 @@ EOAPI void efl_ui_win_iconified_set(Eo *obj, Eina_Bool iconified);
 /**
  * @brief Get the iconified state of a window.
  *
- * @return If true, the window is iconified.
+ * @return If @c true, the window is iconified.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -524,7 +566,7 @@ EOAPI Eina_Bool efl_ui_win_iconified_get(const Eo *obj);
 /**
  * @brief Set the maximized state of a window.
  *
- * @param[in] maximized If true, the window is maximized.
+ * @param[in] maximized If @c true, the window is maximized.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -533,7 +575,7 @@ EOAPI void efl_ui_win_maximized_set(Eo *obj, Eina_Bool maximized);
 /**
  * @brief Get the maximized state of a window.
  *
- * @return If true, the window is maximized.
+ * @return If @c true, the window is maximized.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -563,7 +605,7 @@ EOAPI Eina_Bool efl_ui_win_fullscreen_get(const Eo *obj);
  * Hints the Window Manager that the window in @c obj should be left fixed at
  * its position even when the virtual desktop it's on moves or changes.
  *
- * @param[in] sticky If true, the window's sticky state is enabled.
+ * @param[in] sticky If @c true, the window's sticky state is enabled.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -572,7 +614,7 @@ EOAPI void efl_ui_win_sticky_set(Eo *obj, Eina_Bool sticky);
 /**
  * @brief Get the sticky state of the window.
  *
- * @return If true, the window's sticky state is enabled.
+ * @return If @c true, the window's sticky state is enabled.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -618,13 +660,13 @@ EOAPI Efl_Ui_Win_Modal_Mode efl_ui_win_modal_get(const Eo *obj);
 /**
  * @brief Set the noblank property of a window.
  *
- * The "noblank" property is a way to request the display on which the windowis
- * shown does not blank, screensave or otherwise hide or obscure the window. It
- * is intended for uses such as media playback on a television where a user may
- * not want to be interrupted by an idle screen. The noblank property may have
- * no effect if the window is iconified/minimized or hidden.
+ * The "noblank" property is a way to request the display on which the window
+ * is shown does not blank, screensave or otherwise hide or obscure the window.
+ * It is intended for uses such as media playback on a television where a user
+ * may not want to be interrupted by an idle screen. The noblank property may
+ * have no effect if the window is iconified/minimized or hidden.
  *
- * @param[in] noblank If true, the window is set to noblank.
+ * @param[in] noblank If @c true, the window is set to noblank.
  *
  * @since 1.11
  *
@@ -635,7 +677,7 @@ EOAPI void efl_ui_win_noblank_set(Eo *obj, Eina_Bool noblank);
 /**
  * @brief Get the noblank property of a window.
  *
- * @return If true, the window is set to noblank.
+ * @return If @c true, the window is set to noblank.
  *
  * @since 1.11
  *
@@ -649,7 +691,7 @@ EOAPI Eina_Bool efl_ui_win_noblank_get(const Eo *obj);
  * This function requests the Window Manager to not draw any decoration around
  * the window.
  *
- * @param[in] borderless If true, the window is borderless.
+ * @param[in] borderless If @c true, the window is borderless.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -658,7 +700,7 @@ EOAPI void efl_ui_win_borderless_set(Eo *obj, Eina_Bool borderless);
 /**
  * @brief Get the borderless state of a window.
  *
- * @return If true, the window is borderless.
+ * @return If @c true, the window is borderless.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -697,7 +739,7 @@ EOAPI const char *efl_ui_win_role_get(const Eo *obj);
  *
  * Can only be used at creation time, within @ref eo_add.
  *
- * @param[in] name
+ * @param[in] name Window name
  *
  * @ingroup Efl_Ui_Win
  */
@@ -715,6 +757,8 @@ EOAPI void efl_ui_win_name_set(Eo *obj, const char *name);
  *
  * No description supplied.
  *
+ * @return Window name
+ *
  * @since 1.18
  *
  * @ingroup Efl_Ui_Win
@@ -733,7 +777,7 @@ EOAPI const char *efl_ui_win_name_get(const Eo *obj);
  *
  * Can only be used at creation time, within @ref eo_add.
  *
- * @param[in] type
+ * @param[in] type Window type
  *
  * @ingroup Efl_Ui_Win
  */
@@ -751,6 +795,8 @@ EOAPI void efl_ui_win_type_set(Eo *obj, Efl_Ui_Win_Type type);
  *
  * If the object is not window object, return #ELM_WIN_UNKNOWN.
  *
+ * @return Window type
+ *
  * @ingroup Efl_Ui_Win
  */
 EOAPI Efl_Ui_Win_Type efl_ui_win_type_get(const Eo *obj);
@@ -759,7 +805,7 @@ EOAPI Efl_Ui_Win_Type efl_ui_win_type_get(const Eo *obj);
  * @brief The hardware acceleration preference for this window.
  *
  * This is a constructor function, and can only be called before
- * @ref eo_finalize.
+ * @ref efl_finalize.
  *
  * This property overrides the global EFL configuration option
  * "accel_preference" for this single window, and accepts the same syntax.
@@ -795,7 +841,7 @@ EOAPI Efl_Ui_Win_Type efl_ui_win_type_get(const Eo *obj);
  * Note that this option may be overriden by environment variables or the
  * configuration option "accel_preference_override".
  *
- * @param[in] accel
+ * @param[in] accel Acceleration
  *
  * @since 1.18
  *
@@ -807,7 +853,7 @@ EOAPI void efl_ui_win_accel_preference_set(Eo *obj, const char *accel);
  * @brief The hardware acceleration preference for this window.
  *
  * This is a constructor function, and can only be called before
- * @ref eo_finalize.
+ * @ref efl_finalize.
  *
  * This property overrides the global EFL configuration option
  * "accel_preference" for this single window, and accepts the same syntax.
@@ -846,6 +892,8 @@ EOAPI void efl_ui_win_accel_preference_set(Eo *obj, const char *accel);
  * This will return the value of "accel_preference" when the window was
  * created.
  *
+ * @return Acceleration
+ *
  * @since 1.18
  *
  * @ingroup Efl_Ui_Win
@@ -870,6 +918,8 @@ EOAPI void efl_ui_win_available_profiles_set(Eo *obj, const char **profiles, uns
  * @param[out] profiles The string array of available profiles.
  * @param[out] count The number of members in profiles.
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @since 1.8
  *
  * @ingroup Efl_Ui_Win
@@ -905,6 +955,104 @@ EOAPI void efl_ui_win_alpha_set(Eo *obj, Eina_Bool alpha);
  */
 EOAPI Eina_Bool efl_ui_win_alpha_get(const Eo *obj);
 
+#ifdef EFL_UI_WIN_BETA
+/**
+ * @brief Get the stack ID string of the window as an opaque string.
+ *
+ * This ID is immutable and can never be modified. It will be an opaque string
+ * that has no specific desfined format or content other than it being a string
+ * (no character with a value of 0).
+ *
+ * This string is intended for use as a stack master ID to be use by other
+ * windows to make this window part of a stack of windows to be placed on top
+ * of eachother as if they are a series of dialogs or questions one after the
+ * other and that you may go back through history.
+ *
+ * @return An opaque string that has no specific format, but identified a
+ * specific unique window on the display.
+ *
+ * @ingroup Efl_Ui_Win
+ */
+EOAPI const char *efl_ui_win_stack_id_get(const Eo *obj);
+#endif
+
+#ifdef EFL_UI_WIN_BETA
+/**
+ * @brief Set the window stack ID to use as the master top-level.
+ *
+ * This sets the ID string to be used as the master top-level window as the
+ * base of a stack of windows. This must be set before the first time the
+ * window is shown and should never be changed after that point in time ever
+ * again.
+ *
+ * @param[in] id An opaque string that has no specific format, but identified a
+ * specific unique window on the display.
+ *
+ * @ingroup Efl_Ui_Win
+ */
+EOAPI void efl_ui_win_stack_master_id_set(Eo *obj, const char *id);
+#endif
+
+#ifdef EFL_UI_WIN_BETA
+/**
+ * @brief Get the stack master Id that has been set.
+ *
+ * @return An opaque string that has no specific format, but identified a
+ * specific unique window on the display.
+ *
+ * @ingroup Efl_Ui_Win
+ */
+EOAPI const char *efl_ui_win_stack_master_id_get(const Eo *obj);
+#endif
+
+#ifdef EFL_UI_WIN_BETA
+/**
+ * @brief The stack base state of this window
+ *
+ * This is a boolean flag that determines if this window will become the base
+ * of a stack at all. You must enable this on a base (bottom of a window stack
+ * for things to work correctly.
+ *
+ * This state should be set before a window is shown for the first time and
+ * never changed again after that.
+ *
+ * @param[in] base @c true if this is a stack base window, @c false otherwise.
+ *
+ * @ingroup Efl_Ui_Win
+ */
+EOAPI void efl_ui_win_stack_base_set(Eo *obj, Eina_Bool base);
+#endif
+
+#ifdef EFL_UI_WIN_BETA
+/**
+ * @brief The stack base state of this window
+ *
+ * This is a boolean flag that determines if this window will become the base
+ * of a stack at all. You must enable this on a base (bottom of a window stack
+ * for things to work correctly.
+ *
+ * This state should be set before a window is shown for the first time and
+ * never changed again after that.
+ *
+ * @return @c true if this is a stack base window, @c false otherwise.
+ *
+ * @ingroup Efl_Ui_Win
+ */
+EOAPI Eina_Bool efl_ui_win_stack_base_get(const Eo *obj);
+#endif
+
+#ifdef EFL_UI_WIN_BETA
+/**
+ * @brief Pop (delete) all windows in the stack above this window.
+ *
+ * This will try and delete all the windows in the stack that are above the
+ * window.
+ *
+ * @ingroup Efl_Ui_Win
+ */
+EOAPI void efl_ui_win_stack_pop_to(Eo *obj);
+#endif
+
 /**
  * @brief Create a socket to provide the service for Plug widget.
  *
@@ -916,6 +1064,8 @@ EOAPI Eina_Bool efl_ui_win_alpha_get(const Eo *obj);
  * service all users can connect to, otherwise the service is private to the
  * user id that created the service.
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @ingroup Efl_Ui_Win
  */
 EOAPI Eina_Bool efl_ui_win_socket_listen(Eo *obj, const char *svcname, int svcnum, Eina_Bool svcsys);
@@ -951,10 +1101,10 @@ EOAPI void efl_ui_win_raise(Eo *obj);
  * This function centers window @c obj horizontally and/or vertically based on
  * the values of @c h and @c v.
  *
- * @param[in] h If true, center horizontally. If false, do not change
+ * @param[in] h If @c true, center horizontally. If @c false, do not change
  * horizontal location.
- * @param[in] v If true, center vertically. If false, do not change vertical
- * location.
+ * @param[in] v If @c true, center vertically. If @c false, do not change
+ * vertical location.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -966,17 +1116,19 @@ EOAPI void efl_ui_win_center(Eo *obj, Eina_Bool h, Eina_Bool v);
  * This function grabs the @c key of window using @c grab_mode.
  *
  * @param[in] key This string is the keyname to grab.
- * @param[in] modifiers This is for the keymask feature. Currently this feature
- * is not supported.
- * @param[in] not_modifiers This is for the keymask feature. Currently this
- * feature is not supported.
- * @param[in] proirity This is for the priority of keygrab. Currently this
- * feature is not supported.
- * @param[in] grab_mode According to the grabmode, it can grab key differently.
+ * @param[in] modifiers A combinaison of modifier keys that must be present to
+ * trigger the event. Not supported yet.
+ * @param[in] not_modifiers A combinaison of modifier keys that must not be
+ * present to trigger the event. Not supported yet.
+ * @param[in] priority Not supported yet.
+ * @param[in] grab_mode Describes how the key should be grabbed, wrt. focus and
+ * stacking.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_keygrab_set(Eo *obj, const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, int proirity, Efl_Ui_Win_Keygrab_Mode grab_mode);
+EOAPI Eina_Bool efl_ui_win_keygrab_set(Eo *obj, const char *key, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, int priority, Efl_Ui_Win_Keygrab_Mode grab_mode);
 
 /**
  * @brief Unset keygrab value of the window
@@ -984,165 +1136,194 @@ EOAPI Eina_Bool efl_ui_win_keygrab_set(Eo *obj, const char *key, Evas_Modifier_M
  * This function unset keygrab value. Ungrab @c key of window.
  *
  * @param[in] key This string is the keyname to grab.
- * @param[in] modifiers This is for the keymask feature. Currently this feature
- * is not supported.
- * @param[in] not_modifiers This is for the keymask feature. Currently this
- * feature is not supported.
+ * @param[in] modifiers A combinaison of modifier keys that must be present to
+ * trigger the event. Not supported yet.
+ * @param[in] not_modifiers A combinaison of modifier keys that must not be
+ * present to trigger the event. Not supported yet.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_keygrab_unset(Eo *obj, const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
+EOAPI Eina_Bool efl_ui_win_keygrab_unset(Eo *obj, const char *key, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers);
 
 /**
- * @brief Notify the compositor that a uri should be preloaded
+ * @brief Start moving or resizing the window.
  *
- * @param[in] uri This is the uri to notify with
+ * The user can request the display server to start moving or resizing the
+ * window by combining modes from @ref Efl_Ui_Win_Move_Resize_Mode. This API
+ * can only be called if none of the following conditions is true:
  *
- * @since 1.18
+ * 1. Called in the absence of a pointer down event, 2. Called more than once
+ * before a pointer up event, 3. Called when the window is already being
+ * resized or moved, 4. Called with an unsupported combination of modes.
+ *
+ * Right usage: 1. Pointer (mouse or touch) down event, 2.
+ * @ref efl_ui_win_move_resize_start called only once with a supported mode, 3.
+ * Pointer (mouse or touch) up event.
+ *
+ * If a pointer up event occurs after calling the function, it automatically
+ * ends the window move and resize operation.
+ *
+ * Currently, only the following 9 combinations are allowed, and possibly more
+ * combinations may be added in the future: 1. @ref EFL_UI_WIN_MOVE_RESIZE_MOVE
+ * 2. @ref EFL_UI_WIN_MOVE_RESIZE_TOP 3. @ref EFL_UI_WIN_MOVE_RESIZE_BOTTOM 4.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_LEFT 5. @ref EFL_UI_WIN_MOVE_RESIZE_RIGHT 6.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_TOP | @ref EFL_UI_WIN_MOVE_RESIZE_LEFT 7.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_TOP | @ref EFL_UI_WIN_MOVE_RESIZE_RIGHT 8.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_BOTTOM | @ref EFL_UI_WIN_MOVE_RESIZE_LEFT 9.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_BOTTOM | @ref EFL_UI_WIN_MOVE_RESIZE_RIGHT
+ *
+ * In particular move and resize can not happen simultaneously.
+ *
+ * @note the result of this API can only guarantee that the request has been
+ * forwarded to the server, but there is no guarantee that the request can be
+ * processed by the display server.
+ *
+ * @param[in] mode The requested move or resize mode.
+ *
+ * @return @c true if the request was successfully sent to the display server,
+ * @c false in case of error.
+ *
+ * @since 1.19
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_teamwork_uri_preload(Eo *obj, const char *uri);
+EOAPI Eina_Bool efl_ui_win_move_resize_start(Eo *obj, Efl_Ui_Win_Move_Resize_Mode mode);
 
-/**
- * @brief Notify the compositor that a uri should be displayed
- *
- * Sends the current mouse coordinates as a hint for displaying the related uri
- * in the compositor.
- *
- * @param[in] uri This is the uri to notify with
- *
- * @since 1.18
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_DELETE_REQUEST;
+
+/** Called when the window got a delete request
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_teamwork_uri_show(Eo *obj, const char *uri);
-
-/**
- * @brief Notify the compositor that a uri should be hidden
- *
- * Hides any uri-related media displayed in the compositor through previous
- * @ref elm_win_teamwork_uri_show request
- *
- * @since 1.18
- *
- * @ingroup Efl_Ui_Win
- */
-EOAPI void efl_ui_win_teamwork_uri_hide(Eo *obj);
-
-/**
- * @brief Notify the compositor that a uri should be opened
- *
- * Use the compositor's default application to open a uri
- *
- * @param[in] uri This is the uri to open
- *
- * @since 1.18
- *
- * @ingroup Efl_Ui_Win
- */
-EOAPI void efl_ui_win_teamwork_uri_open(Eo *obj, const char *uri);
-
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_DELETE_REQUEST;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_WITHDRAWN;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_ICONIFIED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_NORMAL;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_STICK;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_UNSTICK;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_FULLSCREEN;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_UNFULLSCREEN;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_MAXIMIZED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_UNMAXIMIZED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_IOERR;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_ROTATION_CHANGED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_PROFILE_CHANGED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_THEME_CHANGED;
-EOAPI extern const Eo_Event_Description _EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU;
-
-/**
- * No description
- */
 #define EFL_UI_WIN_EVENT_DELETE_REQUEST (&(_EFL_UI_WIN_EVENT_DELETE_REQUEST))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WITHDRAWN;
+
+/** Called when window was withdrawn
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_WITHDRAWN (&(_EFL_UI_WIN_EVENT_WITHDRAWN))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_ICONIFIED;
+
+/** Called when window was iconified
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_ICONIFIED (&(_EFL_UI_WIN_EVENT_ICONIFIED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_NORMAL;
+
+/** Called when window got into normal state
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_NORMAL (&(_EFL_UI_WIN_EVENT_NORMAL))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_STICK;
+
+/** Called when window was set sticky
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_STICK (&(_EFL_UI_WIN_EVENT_STICK))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_UNSTICK;
+
+/** Called when window is no  longer set sticky
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_UNSTICK (&(_EFL_UI_WIN_EVENT_UNSTICK))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_FULLSCREEN;
+
+/** Called when window was set fullscreen
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_FULLSCREEN (&(_EFL_UI_WIN_EVENT_FULLSCREEN))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_UNFULLSCREEN;
+
+/** Called when window is no longer set fullscreen
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_UNFULLSCREEN (&(_EFL_UI_WIN_EVENT_UNFULLSCREEN))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MAXIMIZED;
+
+/** Called when window is set maximized
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_MAXIMIZED (&(_EFL_UI_WIN_EVENT_MAXIMIZED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_UNMAXIMIZED;
+
+/** Called when window is no longer set maximized
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_UNMAXIMIZED (&(_EFL_UI_WIN_EVENT_UNMAXIMIZED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_IOERR;
+
+/** Called on input output error
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_IOERR (&(_EFL_UI_WIN_EVENT_IOERR))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED;
+
+/** Called when indicator property changed
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED (&(_EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_ROTATION_CHANGED;
+
+/** Called when window rotation changed
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_ROTATION_CHANGED (&(_EFL_UI_WIN_EVENT_ROTATION_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PROFILE_CHANGED;
+
+/** Called when profile changed
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_PROFILE_CHANGED (&(_EFL_UI_WIN_EVENT_PROFILE_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED;
+
+/** Called when window manager rotation changed
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED (&(_EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_THEME_CHANGED;
+
+/** Called when theme changed
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_THEME_CHANGED (&(_EFL_UI_WIN_EVENT_THEME_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU;
+
+/** Called when elementary block menu action happened
+ *
+ * @ingroup Efl_Ui_Win
  */
 #define EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU (&(_EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU))
 
