@@ -13,9 +13,12 @@ typedef Eo Elm_Entry_Internal_Part;
 
 
 #endif
+/** Elementary entry internal part class
+ *
+ * @ingroup Elm_Entry_Internal_Part
+ */
 #define ELM_ENTRY_INTERNAL_PART_CLASS elm_entry_internal_part_class_get()
 
-EWAPI const Eo_Class *elm_entry_internal_part_class_get(void);
-
+EWAPI const Efl_Class *elm_entry_internal_part_class_get(void);
 
 #endif
