@@ -13,9 +13,12 @@ typedef Eo Elm_Scroller_Internal_Part;
 
 
 #endif
+/** Elementary scroller internal part class
+ *
+ * @ingroup Elm_Scroller_Internal_Part
+ */
 #define ELM_SCROLLER_INTERNAL_PART_CLASS elm_scroller_internal_part_class_get()
 
-EWAPI const Eo_Class *elm_scroller_internal_part_class_get(void);
-
+EWAPI const Efl_Class *elm_scroller_internal_part_class_get(void);
 
 #endif
