@@ -120,6 +120,10 @@
 # endif
 #endif /* ! _WIN32 */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifndef EFL_NOLEGACY_API_SUPPORT
 #include "Emotion_Legacy.h"
 #endif
@@ -192,6 +196,12 @@ enum _Emotion_Meta_Info
    EMOTION_META_INFO_TRACK_COUNT /**< track count - number of the track in the album */
 };
 
+enum _Emotion_Artwork_Info
+{
+   EMOTION_ARTWORK_IMAGE,
+   EMOTION_ARTWORK_PREVIEW_IMAGE
+};
+
 /**
  * @enum _Emotion_Vis
  *
@@ -262,30 +272,28 @@ typedef enum _Emotion_Event     Emotion_Event;
 typedef enum _Emotion_Meta_Info Emotion_Meta_Info; /**< Meta info type to be retrieved. */
 typedef enum _Emotion_Vis       Emotion_Vis; /**< Type of visualization. */
 typedef enum _Emotion_Aspect    Emotion_Aspect; /**< Aspect ratio option. */
+typedef enum _Emotion_Artwork_Info Emotion_Artwork_Info;
 
 #define EMOTION_CHANNEL_AUTO -1
 #define EMOTION_CHANNEL_DEFAULT 0
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #define EMOTION_VERSION_MAJOR EFL_VERSION_MAJOR
 #define EMOTION_VERSION_MINOR EFL_VERSION_MINOR
-   /**
-    * @typedef Emotion_Version
-    * Represents the current version of Emotion
-    */
-   typedef struct _Emotion_Version
-     {
-        int major; /** < major (binary or source incompatible changes) */
-        int minor; /** < minor (new features, bugfixes, major improvements version) */
-        int micro; /** < micro (bugfix, internal improvements, no new features version) */
-        int revision; /** < git revision (0 if a proper release or the git revision number Emotion is built from) */
-     } Emotion_Version;
-   
-   EAPI extern Emotion_Version *emotion_version;
-   
+
+/**
+ * @typedef Emotion_Version
+ * Represents the current version of Emotion
+ */
+typedef struct _Emotion_Version
+  {
+     int major; /** < major (binary or source incompatible changes) */
+     int minor; /** < minor (new features, bugfixes, major improvements version) */
+     int micro; /** < micro (bugfix, internal improvements, no new features version) */
+     int revision; /** < git revision (0 if a proper release or the git revision number Emotion is built from) */
+  } Emotion_Version;
+
+EAPI extern Emotion_Version *emotion_version;
+
 /* api calls available */
 
 /**
@@ -873,7 +881,7 @@ EAPI Eina_Bool    emotion_object_smooth_scale_get      (const Evas_Object *obj);
  * @param obj The object target of the event.
  * @param ev The emotion event.
  *
- * @see Emotion_Event 
+ * @see Emotion_Event
  */
 EAPI void         emotion_object_event_simple_send     (Evas_Object *obj, Emotion_Event ev);
 
@@ -1339,6 +1347,19 @@ EAPI const char      *emotion_webcam_name_get(const Emotion_Webcam *ew);
  */
 EAPI const char      *emotion_webcam_device_get(const Emotion_Webcam *ew);
 
+/**
+ * @brief Get the album artwork from file meta data tags.
+ *
+ * @param obj The evas object we are working with.
+ * @param path The local path for the file.
+ * @param type The metadata location type (GST_IMAGE_PREVIEW_IMAGE or GST_PREVIEW).
+ *
+ * @ingroup Emotion_Artwork
+ *
+ * @since 1.19
+ */
+
+EAPI Evas_Object     *emotion_file_meta_artwork_get(const Evas_Object *obj, const char *path, Emotion_Artwork_Info type);
 /**
  * @}
  */
