@@ -29,7 +29,7 @@ typedef Eo Evas_Box;
  * See also @ref evas_object_box_align_get.
  *
  * @param[in] horizontal The horizontal alignment, in pixels.
- * @param[in] vertical the vertical alignment, in pixels.
+ * @param[in] vertical The vertical alignment, in pixels.
  *
  * @ingroup Evas_Box
  */
@@ -42,7 +42,7 @@ EAPI void evas_object_box_align_set(Evas_Box *obj, double horizontal, double ver
  * See also @ref evas_object_box_align_set for more information.
  *
  * @param[out] horizontal The horizontal alignment, in pixels.
- * @param[out] vertical the vertical alignment, in pixels.
+ * @param[out] vertical The vertical alignment, in pixels.
  *
  * @ingroup Evas_Box
  */
@@ -56,11 +56,11 @@ EAPI void evas_object_box_align_get(const Evas_Box *obj, double *horizontal, dou
  * See also @ref evas_object_box_padding_get.
  *
  * @param[in] horizontal The horizontal padding, in pixels.
- * @param[in] vertical the vertical padding, in pixels.
+ * @param[in] vertical The vertical padding, in pixels.
  *
  * @ingroup Evas_Box
  */
-EAPI void evas_object_box_padding_set(Evas_Box *obj, Evas_Coord horizontal, Evas_Coord vertical);
+EAPI void evas_object_box_padding_set(Evas_Box *obj, int horizontal, int vertical);
 
 /**
  * @brief Get the (space) padding between cells set for a given box object.
@@ -68,11 +68,11 @@ EAPI void evas_object_box_padding_set(Evas_Box *obj, Evas_Coord horizontal, Evas
  * See also @ref evas_object_box_padding_set.
  *
  * @param[out] horizontal The horizontal padding, in pixels.
- * @param[out] vertical the vertical padding, in pixels.
+ * @param[out] vertical The vertical padding, in pixels.
  *
  * @ingroup Evas_Box
  */
-EAPI void evas_object_box_padding_get(const Evas_Box *obj, Evas_Coord *horizontal, Evas_Coord *vertical);
+EAPI void evas_object_box_padding_get(const Evas_Box *obj, int *horizontal, int *vertical);
 
 /**
  * @brief Set a new layouting function to a given box object
@@ -145,7 +145,8 @@ EAPI void evas_object_box_layout_set(Evas_Box *obj, Evas_Object_Box_Layout cb, c
  * bounded to a minimum or maximum size, those size hints must be set, by the
  * evas_object_size_hint_{min,max}_set functions.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
@@ -158,7 +159,8 @@ EAPI void evas_object_box_layout_horizontal(Evas_Box *obj, Evas_Object_Box_Data
  * description of its behaviour can be derived from that function's
  * documentation.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
@@ -201,12 +203,14 @@ EAPI void evas_object_box_layout_vertical(Evas_Box *obj, Evas_Object_Box_Data *p
  * box try to resize this child element to the exact height of its parent
  * (respecting the max hint on the child's height).
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
 EAPI void evas_object_box_layout_homogeneous_max_size_horizontal(Evas_Box *obj, Evas_Object_Box_Data *priv, void *data);
 
+
 /**
  * @brief Layout function which sets the box o to a flow vertical box.
  *
@@ -214,12 +218,14 @@ EAPI void evas_object_box_layout_homogeneous_max_size_horizontal(Evas_Box *obj,
  * The description of its behaviour can be derived from that function's
  * documentation.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
 EAPI void evas_object_box_layout_flow_vertical(Evas_Box *obj, Evas_Object_Box_Data *priv, void *data);
 
+
 /**
  * @brief Insert a new child object after another existing one, in a given box
  * object o.
@@ -234,6 +240,7 @@ EAPI void evas_object_box_layout_flow_vertical(Evas_Box *obj, Evas_Object_Box_Da
  * @note This call will trigger the box's _Evas_Object_Box_Api.insert_after
  * smart function.
  *
+ * @param[in] child A child Evas object to be made a member of @c o.
  * @param[in] reference The child object to place this new one after.
  *
  * @return A box option bound to the recently added box item or @c null, on
@@ -241,7 +248,7 @@ EAPI void evas_object_box_layout_flow_vertical(Evas_Box *obj, Evas_Object_Box_Da
  *
  * @ingroup Evas_Box
  */
-EAPI Evas_Object_Box_Option *evas_object_box_insert_after(Evas_Box *obj, Evas_Object *child, const Evas_Object *reference) EINA_ARG_NONNULL(2, 3);
+EAPI Evas_Object_Box_Option *evas_object_box_insert_after(Evas_Box *obj, Efl_Canvas_Object *child, const Efl_Canvas_Object *reference) EINA_ARG_NONNULL(2, 3);
 
 /**
  * @brief Remove all child objects from a box object, unparenting them again.
@@ -250,9 +257,9 @@ EAPI Evas_Object_Box_Option *evas_object_box_insert_after(Evas_Box *obj, Evas_Ob
  * child objects, in sequence. If, and only if, all those calls succeed, so
  * does this one.
  *
- * @param[in] clear if true, it will delete just removed children.
+ * @param[in] clear If @c true, it will delete just removed children.
  *
- * @return @c true, on success, @c false otherwise.
+ * @return @c true on success, @c false otherwise.
  *
  * @ingroup Evas_Box
  */
@@ -280,7 +287,7 @@ EAPI Eina_Iterator *evas_object_box_iterator_new(const Evas_Box *obj) EINA_WARN_
  *
  * @ingroup Evas_Box
  */
-EAPI Evas_Object *evas_object_box_add_to(Evas_Box *obj) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_box_add_to(Evas_Box *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Append a new child object to the given box object o.
@@ -301,7 +308,7 @@ EAPI Evas_Object *evas_object_box_add_to(Evas_Box *obj) EINA_WARN_UNUSED_RESULT;
  *
  * @ingroup Evas_Box
  */
-EAPI Evas_Object_Box_Option *evas_object_box_append(Evas_Box *obj, Evas_Object *child) EINA_ARG_NONNULL(2);
+EAPI Evas_Object_Box_Option *evas_object_box_append(Evas_Box *obj, Efl_Canvas_Object *child) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Get the numerical identifier of the property of the child elements of
@@ -341,7 +348,7 @@ EAPI int evas_object_box_option_property_id_get(const Evas_Box *obj, const char
  *
  * @ingroup Evas_Box
  */
-EAPI Evas_Object_Box_Option *evas_object_box_prepend(Evas_Box *obj, Evas_Object *child) EINA_ARG_NONNULL(2);
+EAPI Evas_Object_Box_Option *evas_object_box_prepend(Evas_Box *obj, Efl_Canvas_Object *child) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Get an accessor (a structure providing random items access) to the
@@ -356,6 +363,9 @@ EAPI Evas_Object_Box_Option *evas_object_box_prepend(Evas_Box *obj, Evas_Object
  */
 EAPI Eina_Accessor *evas_object_box_accessor_new(const Evas_Box *obj) EINA_WARN_UNUSED_RESULT;
 
+
+
+
 /**
  * @brief Remove an object, bound to a given position in a box object,
  * unparenting it again.
@@ -380,6 +390,8 @@ EAPI Eina_Accessor *evas_object_box_accessor_new(const Evas_Box *obj) EINA_WARN_
  */
 EAPI Eina_Bool evas_object_box_remove_at(Evas_Box *obj, unsigned int pos);
 
+
+
 /**
  * @brief Insert a new child object before another existing one, in a given box
  * object o.
@@ -394,6 +406,7 @@ EAPI Eina_Bool evas_object_box_remove_at(Evas_Box *obj, unsigned int pos);
  * @note This call will trigger the box's _Evas_Object_Box_Api.insert_before
  * smart function.
  *
+ * @param[in] child A child Evas object to be made a member of @c o.
  * @param[in] reference The child object to place this new one before.
  *
  * @return A box option bound to the recently added box item or @c null, on
@@ -401,7 +414,7 @@ EAPI Eina_Bool evas_object_box_remove_at(Evas_Box *obj, unsigned int pos);
  *
  * @ingroup Evas_Box
  */
-EAPI Evas_Object_Box_Option *evas_object_box_insert_before(Evas_Box *obj, Evas_Object *child, const Evas_Object *reference) EINA_ARG_NONNULL(2, 3);
+EAPI Evas_Object_Box_Option *evas_object_box_insert_before(Evas_Box *obj, Efl_Canvas_Object *child, const Efl_Canvas_Object *reference) EINA_ARG_NONNULL(2, 3);
 
 /**
  * @brief Get the name of the property of the child elements of the box o which
@@ -423,6 +436,7 @@ EAPI Evas_Object_Box_Option *evas_object_box_insert_before(Evas_Box *obj, Evas_O
  */
 EAPI const char *evas_object_box_option_property_name_get(const Evas_Box *obj, int property) EINA_WARN_UNUSED_RESULT;
 
+
 /**
  * @brief Layout function which sets the box o to a homogeneous horizontal box
  *
@@ -452,12 +466,14 @@ EAPI const char *evas_object_box_option_property_name_get(const Evas_Box *obj, i
  * box try to resize this child element to the exact height of its parent
  * (respecting the maximum size hint on the child's height).
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
 EAPI void evas_object_box_layout_homogeneous_horizontal(Evas_Box *obj, Evas_Object_Box_Data *priv, void *data);
 
+
 /**
  * @brief Layout function which sets the box o to a maximum size, homogeneous
  * vertical box
@@ -466,12 +482,14 @@ EAPI void evas_object_box_layout_homogeneous_horizontal(Evas_Box *obj, Evas_Obje
  * evas_object_box_layout_homogeneous_max_size_horizontal. The description of
  * its behaviour can be derived from that function's documentation.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
 EAPI void evas_object_box_layout_homogeneous_max_size_vertical(Evas_Box *obj, Evas_Object_Box_Data *priv, void *data);
 
+
 /**
  * @brief Insert a new child object at a given position, in a given box object
  * @c o.
@@ -487,6 +505,7 @@ EAPI void evas_object_box_layout_homogeneous_max_size_vertical(Evas_Box *obj, Ev
  * @note This call will trigger the box's _Evas_Object_Box_Api.insert_at smart
  * function.
  *
+ * @param[in] child A child Evas object to be made a member of @c o.
  * @param[in] pos The numeric position (starting from $0) to place the new
  * child object at.
  *
@@ -495,7 +514,8 @@ EAPI void evas_object_box_layout_homogeneous_max_size_vertical(Evas_Box *obj, Ev
  *
  * @ingroup Evas_Box
  */
-EAPI Evas_Object_Box_Option *evas_object_box_insert_at(Evas_Box *obj, Evas_Object *child, unsigned int pos) EINA_ARG_NONNULL(2);
+EAPI Evas_Object_Box_Option *evas_object_box_insert_at(Evas_Box *obj, Efl_Canvas_Object *child, unsigned int pos) EINA_ARG_NONNULL(2);
+
 
 /**
  * @brief Remove a given object from a box object, unparenting it again.
@@ -514,7 +534,7 @@ EAPI Evas_Object_Box_Option *evas_object_box_insert_at(Evas_Box *obj, Evas_Objec
  *
  * @ingroup Evas_Box
  */
-EAPI Eina_Bool evas_object_box_remove(Evas_Box *obj, Evas_Object *child) EINA_ARG_NONNULL(2);
+EAPI Eina_Bool evas_object_box_remove(Evas_Box *obj, Efl_Canvas_Object *child) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Layout function which sets the box o to a stacking box
@@ -534,7 +554,8 @@ EAPI Eina_Bool evas_object_box_remove(Evas_Box *obj, Evas_Object *child) EINA_AR
  * (respecting the min and max hints on the child's width and accounting for
  * its horizontal padding properties). The same applies to the vertical axis.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
@@ -547,7 +568,8 @@ EAPI void evas_object_box_layout_stack(Evas_Box *obj, Evas_Object_Box_Data *priv
  * evas_object_box_layout_homogeneous_horizontal.  The description of its
  * behaviour can be derived from that function's documentation.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
@@ -583,10 +605,12 @@ EAPI void evas_object_box_layout_homogeneous_vertical(Evas_Box *obj, Evas_Object
  * dictates positioning relative to the largest height required by a child
  * object in the actual row.
  *
- * @param[in] data
+ * @param[in] priv Private data pointer
+ * @param[in] data Data pointer
  *
  * @ingroup Evas_Box
  */
 EAPI void evas_object_box_layout_flow_horizontal(Evas_Box *obj, Evas_Object_Box_Data *priv, void *data);
 
+
 #endif
