@@ -13,9 +13,13 @@ typedef Eo Evas_Canvas3D_Primitive;
 
 
 #endif
+/** Evas 3D canvas primitive class
+ *
+ * @ingroup Evas_Canvas3D_Primitive
+ */
 #define EVAS_CANVAS3D_PRIMITIVE_CLASS evas_canvas3d_primitive_class_get()
 
-EWAPI const Eo_Class *evas_canvas3d_primitive_class_get(void);
+EWAPI const Efl_Class *evas_canvas3d_primitive_class_get(void);
 
 /**
  * @brief Set the form of the given primitive.
@@ -153,14 +157,14 @@ EOAPI void evas_canvas3d_primitive_surface_set(Eo *obj, Evas_Canvas3D_Surface_Fu
  * @brief Set the texture scale of the given primitive.
  *
  * Texture scale uses in all non tabulated primitives and defines scale of
- * texture coords or primitives.
+ * texture coordinates or primitives.
  *
  * It uses to create periodical textured meshes.
  *
  * Default tex_scale is {1.0, 1.0}
  *
- * @param[in] tex_scale_x
- * @param[in] tex_scale_y
+ * @param[in] tex_scale_x Texture scale X coordinate
+ * @param[in] tex_scale_y Texture scale Y coordinate
  *
  * @ingroup Evas_Canvas3D_Primitive
  */
@@ -171,12 +175,11 @@ EOAPI void evas_canvas3d_primitive_tex_scale_set(Eo *obj, Evas_Real tex_scale_x,
  *
  * See also @ref evas_canvas3d_primitive_tex_scale_set.
  *
- * @param[out] tex_scale_x
- * @param[out] tex_scale_y
+ * @param[out] tex_scale_x Texture scale X coordinate
+ * @param[out] tex_scale_y Texture scale Y coordinate
  *
  * @ingroup Evas_Canvas3D_Primitive
  */
 EOAPI void evas_canvas3d_primitive_tex_scale_get(const Eo *obj, Evas_Real *tex_scale_x, Evas_Real *tex_scale_y);
 
-
 #endif
